@@ -27,10 +27,9 @@ GetSP500Stocks <- function(do.cache = TRUE,
     }
   }
 
-  my.url <- 'https://en.wikipedia.org/wiki/List_of_S%26P_500_companies'
+    my.url <- 'https://en.wikipedia.org/wiki/List_of_S%26P_500_companies'
 
   read_html <- 0 # fix for global variable nagging from BUILD
-  my.xpath <- '//*[@id="mw-content-text"]/div/table[2]' # old xpath
   my.xpath <- '//*[@id="constituents"]'
   df.SP500Stocks <- my.url %>%
     read_html() %>%
@@ -39,8 +38,8 @@ GetSP500Stocks <- function(do.cache = TRUE,
 
   df.SP500Stocks <- df.SP500Stocks[[1]]
 
-  colnames(df.SP500Stocks) <- c('company','tickers','SEC.filings','GICS.Sector',
-                                'GICS.Sub.Industry','Address','Date.first.added','CIK', 'Founded')
+  colnames(df.SP500Stocks) <- c('Tickers','Company','SEC.filings','GICS.Sector',
+                                'GICS.Sub.Industry','HQ.Location','Date.First.Added','CIK', 'Founded')
 
   if (do.cache) {
     if (!dir.exists(cache.folder)) dir.create(cache.folder)
